@@ -311,7 +311,8 @@ def create_temp_dir(folder: Optional[str]=None,
         msg = "Failed to create temporary directory in %s: %s %s" % (
                       folder,
                       inst.errno,
-                      inst.strerror)
+                      inst.strerror
+        )
         logging.critical(msg)
         temp_dir = None
     return temp_dir
@@ -942,4 +943,13 @@ def image_large_enough_fdo(size: QSize) -> bool:
      specs for a large thumbnail
     """
 
-    return size.width() >= 256 or size.height() >= 256
\ No newline at end of file
+    return size.width() >= 256 or size.height() >= 256
+
+
+def is_venv():
+    """
+    :return: True if the python interpreter is running in venv or virtualenv
+    """
+
+    return hasattr(sys, 'real_prefix') or \
+           (hasattr(sys, 'base_prefix') and sys.base_prefix != sys.prefix)
\ No newline at end of file
